# `causal-hub`

![Static Badge](https://img.shields.io/badge/info-general-blue)
![Crates.io License](https://img.shields.io/crates/l/causal-hub)
![Static Badge](https://img.shields.io/badge/platform-linux--x64_%7C_macos--arm64_%7C_windows--x64-blue)  
![Static Badge](https://img.shields.io/badge/info-rust-blue)
![Crates.io Version](https://img.shields.io/crates/v/causal-hub)
![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/AlessioZanga/causal-hub/rust-test.yml?branch=develop)
![docs.rs](https://img.shields.io/docsrs/causal-hub)
![Crates.io MSRV](https://img.shields.io/crates/msrv/causal-hub)  
![Static Badge](https://img.shields.io/badge/info-python-blue)
![PyPI - Version](https://img.shields.io/pypi/v/causal-hub)
![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/AlessioZanga/causal-hub/python-test.yml?branch=develop)
![Read the Docs](https://img.shields.io/readthedocs/causal-hub)
![Python Version from PEP 621 TOML](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2FAlessioZanga%2Fcausal-hub%2Fmain%2Fpyproject.toml)


`causal-hub` is a library for causal models, inference and discovery.

## Introduction

`causal-hub` provides a unified interface for working with causal models, enabling users to easily define, manipulate, and infer causal relationships in their data.

The library is designed with a Rust backend, ensuring high performance and safety, with a Python frontend for ease of use in data science workflows.

## Installation

To use `causal-hub` in your Rust project, add the following to your `Cargo.toml`:

```toml
[dependencies]
causal-hub = "*"
```

To use `causal-hub` in your Python project, you can install it via pip:

```bash
pip install causal-hub
```

## Changelog

All notable changes to this project will be documented in the [CHANGELOG](CHANGELOG.md) file.

## License
This software is distributed under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE, Version 3.

See the [LICENSE](LICENSE) file for a copy of the license.

## Versioning
This software follows the [SemVer](https://semver.org/) specification.
